// The contents of this file are subject to the Mozilla Public License Version 1.1
// (the "License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
// 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
// WARRANTY OF ANY KIND, either express or implied. See the License for the specific
// language governing rights and limitations under the License.
// 
// The Original Code is the Venice Web Communities System.
// 
// The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
// for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
// Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
// 
// Contributor(s): 

importPackage(Packages.com.silverwrist.venice.core);
importPackage(Packages.com.silverwrist.venice.except);
importPackage(Packages.com.silverwrist.venice.ui);
importPackage(Packages.com.silverwrist.venice.ui.helpers);
importPackage(Packages.com.silverwrist.venice.ui.view);

// get the request object and the community
rinput = bsf.lookupBean("request");
comm = rinput.getCommunity(true,"top.js.vs");

rc = null;
try
{ // retrieve certain possibly problematic data items and save them as attributes
  ci = comm.getContactInfo();
  rinput.setRequestAttribute("contact.info",ci);
  rinput.setRequestAttribute("host.profile",comm.getHostProfile());
  rinput.setRequestAttribute("category",comm.getCategory());

  // determine the last line of the address and save it off
  buf = null;
  if (vlib.emptyString(ci.locality))
  { // allocate stringbuffer based on region
    if (vlib.emptyString(ci.region))
      buf = new java.lang.StringBuffer();
    else
      buf = new java.lang.StringBuffer(ci.region);

  } // end if
  else if (vlib.emptyString(ci.region))
    buf = new java.lang.StringBuffer(ci.locality);
  else
  { // tack together both locality and region
    buf = new java.lang.StringBuffer(ci.locality);
    buf.append(", ");
    buf.append(ci.region);

  } // end else

  if (!(vlib.emptyString(ci.postalCode)))
  { // append the postal code
    buf.append(" ");
    buf.append(ci.postalCode);

  } // end if

  rinput.setRequestAttribute("address.lastline",buf.toString());

  // get the full country name and save it off
  ce = Packages.com.silverwrist.util.International.get().getCountryForCode(ci.country);
  if (ce!=null)
    rinput.setRequestAttribute("address.country",ce.name);

  // Save off the community logo tag.
  rinput.setRequestAttribute("community.logo",rinput.getCommunityLogoTag(ci.photoURL));

  // create the view object
  rc = new JSPView("Community Profile: " + comm.name,"comm/profile.jsp");
  rc.menuSelector = Content.MENU_SELECTOR_COMMUNITY;
  rc.pageQID = "go/" + comm.alias + "!";

} // end try
catch (e)
{ // handle an exception thrown by the profile code
  etype = vlib.exceptionType(e) + "";
  if (etype.match("DataException"))
    rc = new ErrorBox("Database Error","Database error accessing community: " + e.message,"top.js.vs");
  else
    rc = e;

} // end catch

vlib.output(rc);  // all done!