// The contents of this file are subject to the Mozilla Public License Version 1.1
// (the "License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
// 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
// WARRANTY OF ANY KIND, either express or implied. See the License for the specific
// language governing rights and limitations under the License.
// 
// The Original Code is the Venice Web Communities System.
// 
// The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
// for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
// Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
// 
// Contributor(s): 

importPackage(Packages.com.silverwrist.venice.core);
importPackage(Packages.com.silverwrist.venice.except);
importPackage(Packages.com.silverwrist.venice.ui);
importPackage(Packages.com.silverwrist.venice.ui.conf);
importPackage(Packages.com.silverwrist.venice.ui.helpers);

// get the request object and the community
rinput = bsf.lookupBean("request");
comm = rinput.getCommunity(true,"top.js.vs");

if (!(comm.canManageConferences()))
{ // can't manage conferences, bail out
  vlib.output(new ErrorBox("Access Error","You are not permitted to manage conferences in this community.",
			   "conf/conferences.js.vs?cc=" + comm.communityID));
  vlib.done();

} // end if

// get the current conference
currc = new CurrentConference(rinput);
conf = currc.getConference(true,"conf/conferences.js.vs?cc=" + comm.communityID);

if (!(conf.canDeleteConference()))
{ // you can't fiddle with this conference
  vlib.output(new ErrorBox("Access Error","You do not have permission to delete this conference.",
                           "conf/manage_conf.js.vs?cc=" + comm.communityID + "&conf=" + conf.confID));
  vlib.done();

} // end if

CONFIRM_attr = "conferences.manage.delete.ConfirmBox";
CONFIRM_param = "confirm";

rc = null;
if (ConfirmBox.isConfirmed(rinput,CONFIRM_attr,CONFIRM_param))
{ // it is confirmed - we want to delete the conference!
  try
  { // delete the conference (using the alias function to avoid using the delete keyword)
    conf.deleteConference();

    // trap back to the conferences list
    rc = new Redirect("conf/conferences.js.vs?cc=" + comm.communityID,LinkTypes.SERVLET);

  } // end try
  catch (e)
  { // handle error in deletion
    etype = vlib.exceptionType(e) + "";
    if (etype.match("DataException"))
      rc = new ErrorBox("Database Error","Database error deleting conference: " + e.message,
			"conf/manage_conf.js.vs?cc=" + comm.communityID + "&conf=" + conf.confID);
    else if (etype.match("AccessError"))
      rc = new ErrorBox("Access Error",e.message,
                        "conf/manage_conf.js.vs?cc=" + comm.communityID + "&conf=" + conf.confID);
    else
      rc = e;

  } // end catch

} // end if
else // come up with the confirm box
  rc = new ConfirmBox(rinput,CONFIRM_attr,CONFIRM_param,"Delete Conference",
                      "You are about to permanently delete the '" + conf.name
                      + "' conference!  Are you sure you want to do this?",
                      "conf/delete.js.vs?cc=" + comm.communityID + "&conf=" + conf.confID,LinkTypes.SERVLET,
                      "conf/manage_conf.js.vs?cc=" + comm.communityID + "&conf=" + conf.confID,
                      LinkTypes.SERVLET);

vlib.output(rc);  // all done!
