// The contents of this file are subject to the Mozilla Public License Version 1.1
// (the "License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
// 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
// WARRANTY OF ANY KIND, either express or implied. See the License for the specific
// language governing rights and limitations under the License.
// 
// The Original Code is the Venice Web Communities System.
// 
// The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
// for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
// Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
// 
// Contributor(s): 

importPackage(Packages.com.silverwrist.venice.core);
importPackage(Packages.com.silverwrist.venice.except);
importPackage(Packages.com.silverwrist.venice.ui);
importPackage(Packages.com.silverwrist.venice.ui.conf);
importPackage(Packages.com.silverwrist.venice.ui.helpers);
importPackage(Packages.com.silverwrist.venice.ui.view);

// get the request object and the community
rinput = bsf.lookupBean("request");
comm = rinput.getCommunity(true,"top.js.vs");

// get the current conference
currc = new CurrentConference(rinput);
conf = currc.getConference(true,"conf/conferences.js.vs?cc=" + comm.communityID);
on_error = "conf/manage_conf.js.vs?cc=" + comm.communityID + "&conf=" + conf.confID;

rc = null;
if ("GET"==rinput.verb)
{ // display the dialog
  try
  { // we need the topic list
    tlist = conf.getTopicList(ConferenceContext.DISPLAY_ALL,ConferenceContext.SORT_NAME);
    rinput.setRequestAttribute("topic.email.list",tlist);

    // create the dialog
    rc = new JSPView("Conference E-Mail: " + conf.name,"conf/email.jsp");
    rc.menuSelector = Content.MENU_SELECTOR_COMMUNITY;

  } // end try
  catch (e)
  { // unable to get topic list
    etype = vlib.exceptionType(e) + "";
    if (etype.match("DataException"))
      rc = new ErrorBox("Database Error","Database error setting up dialog: " + e.message,on_error);
    else if (etype.match("AccessError"))
      rc = new ErrorBox("Access Error",e.message,on_error);
    else
      rc = e;

  } // end catch

  vlib.output(rc);
  vlib.done();

} // end if

if (rinput.isImageButtonClicked("cancel"))
{ // cancelled - bail out!
  vlib.output(new Redirect(on_error,LinkTypes.SERVLET));
  vlib.done();

} // end if

if (!(rinput.isImageButtonClicked("send")))
{ // what button got pressed?!?!?
  logger.error("no known button click on POST to conf/email.js");
  vlib.output(new ErrorBox("Internal Error","Unknown command button pressed",on_error));
  vlib.done();

} // end if

try
{ // retrieve the topic we want to send to
  topic = null;
  tnum = rinput.getParameterShort("top",0);
  if (tnum>0)
    topic = conf.getTopic(tnum);

  // retrieve other parameters
  posters = (rinput.getParameterInt("porl",0)==0)
  ndays = -1;
  if ("Y"==rinput.getParameter("xday"))
    ndays = rinput.getParameterInt("day",-1);

  // send the E-mail!
  if (topic!=null)
    topic.sendMailToParticipants(posters,ndays,rinput.getParameter("subj"),rinput.getParameter("pb"));
  else
    conf.sendMailToParticipants(posters,ndays,rinput.getParameter("subj"),rinput.getParameter("pb"));

  // bounce back to the manage conference menu
  rc = new Redirect(on_error,LinkTypes.SERVLET);

} // end try
catch (e)
{ // exception sending the E-mail
  etype = vlib.exceptionType(e) + "";
  if (etype.match("DataException"))
    rc = new ErrorBox("Database Error","Database error sending E-mail: " + e.message,on_error);
  else if (etype.match("AccessError"))
    rc = new ErrorBox("Access Error",e.message,on_error);
  else
    rc = e;

} // end catch

vlib.output(rc);   // all done....
