/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.core;

public class ServiceToken implements Comparable, ServiceGroup
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private int group;
  private String symbol;
  private int index;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  protected ServiceToken(int group, String symbol, int index)
  {
    this.group = group;
    this.symbol = symbol;
    this.index = index;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Overrides from class Object
   *--------------------------------------------------------------------------------
   */

  public boolean equals(Object o)
  {
    if ((o==null) || !(o instanceof ServiceToken))
      return false;
    ServiceToken other = (ServiceToken)o;
    return ((this.group==other.group) && (this.symbol.equals(other.symbol)));

  } // end equals

  public int hashCode()
  {
    return (group << 24) ^ symbol.hashCode();

  } // end hashCode

  public String toString()
  {
    return symbol;

  } // end toString

  /*--------------------------------------------------------------------------------
   * Implementations from interface Comparable
   *--------------------------------------------------------------------------------
   */

  public int compareTo(Object o)
  {
    if (o==null)
      throw new NullPointerException("compareTo null object!");
    ServiceToken other = (ServiceToken)o;  // may throw ClassCastException
    int rc = this.group - other.group;
    if (rc!=0)
      return rc;
    return this.symbol.compareTo(other.symbol);

  } // end compareTo

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public final int getGroup()
  {
    return group;

  } // end getGroup

  public final String getSymbol()
  {
    return symbol;

  } // end getSymbol

  public final int getIndex()
  {
    return index;

  } // end getIndex

} // end class ServiceToken
