/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.core.internals;

import com.silverwrist.venice.except.AccessError;
import com.silverwrist.venice.security.SecurityMonitor;

public class EnvCommunityData extends EnvEngine
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  public static final String PERM_NOJOINREQUIRED = "Community.NoJoinRequired";

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private CommunityDataBackend comm;

  /*--------------------------------------------------------------------------------
   * Constructors
   *--------------------------------------------------------------------------------
   */

  public EnvCommunityData(EnvEngine parent, CommunityDataBackend comm)
  {
    super(parent);
    this.comm = comm;

  } // end constructor

  protected EnvCommunityData(EnvCommunityData other)
  {
    super(other);
    this.comm = other.comm;

  } // end EnvCommunityData

  /*--------------------------------------------------------------------------------
   * Overrides from class EnvEngine
   *--------------------------------------------------------------------------------
   */

  protected SecurityMonitor getStaticMonitor()
  {
    return getEngine().env_getSecurityMonitor(EngineBackend.SM_COMMUNITY);

  } // end getStaticMonitor

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public final CommunityDataBackend getCommunityData()
  {
    return comm;

  } // end getCommunityData

  public final int getCommunityID()
  {
    return comm.realCommunityID();

  } // end getCommunityID

  public final boolean testPermission(String symbol, int level, String errormsg) throws AccessError
  {
    return getStaticMonitor().testPermission(symbol,level,errormsg);

  } // end testPermission

  public final boolean testPermission(String symbol, int level)
  {
    return getStaticMonitor().testPermission(symbol,level);

  } // end testPermission

} // end class EnvCommunityData
