/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.ui.dlg;

import java.io.IOException;
import org.w3c.dom.*;
import com.silverwrist.util.*;
import com.silverwrist.venice.except.*;
import com.silverwrist.venice.ui.*;
import com.silverwrist.venice.util.IDUtils;

public class EMailAddressField extends TextField
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  public static final String TAGNAME = "email";

  /*--------------------------------------------------------------------------------
   * Constructors
   *--------------------------------------------------------------------------------
   */

  public EMailAddressField(String name, String caption, String caption2, boolean required, int size,
			   int maxlength)
  {
    super(name,caption,caption2,required,size,maxlength);

  } // end constructor

  public EMailAddressField(String name, String caption, String caption2, boolean required, int size)
  {
    super(name,caption,caption2,required,size);

  } // end constructor

  public EMailAddressField(Element elt) throws ConfigException
  {
    super(elt);

  } // end constructor

  protected EMailAddressField(EMailAddressField other)
  {
    super(other);

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Overrides from class TextField
   *--------------------------------------------------------------------------------
   */

  protected void validateContents(String value) throws ValidationException
  {
    super.validateContents(value);
    if (!IDUtils.isValidEmailAddress(value))
      throw new ValidationException("The value of '" + getCaption()
				    + "' must be a correct Internet E-mail address.");
    
  } // end validateContents

  /*--------------------------------------------------------------------------------
   * Implementations from interface DialogField
   *--------------------------------------------------------------------------------
   */

  public DialogField duplicate()
  {
    return new EMailAddressField(this);

  } // end duplicate

} // end class EMailAddressField

