/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.ui.dlg;

import java.io.IOException;
import org.w3c.dom.*;
import com.silverwrist.util.*;
import com.silverwrist.venice.except.*;
import com.silverwrist.venice.ui.*;
import com.silverwrist.venice.util.XMLLoader;

public class HiddenField implements DialogField
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  public static final String TAGNAME = "hidden";

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private String name;
  private String value = null;

  /*--------------------------------------------------------------------------------
   * Constructors
   *--------------------------------------------------------------------------------
   */

  public HiddenField(String name, String value)
  {
    this.name = name;
    this.value = value;

  } // end constructor

  public HiddenField(String name)
  {
    this.name = name;
    this.value = null;

  } // end constructor

  public HiddenField(Element elt) throws ConfigException
  {
    XMLLoader loader = XMLLoader.get();
    name = loader.configGetAttribute(elt,"name");
    value = elt.getAttribute("value");

  } // end constructor

  protected HiddenField(HiddenField other)
  {
    this.name = other.name;
    this.value = other.value;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Implementations from interface RenderDirect
   *--------------------------------------------------------------------------------
   */

  public void render(RequestOutput out) throws IOException
  {
    out.write("<INPUT TYPE=\"HIDDEN\" NAME=\"" + name + "\" VALUE=\"");
    if (value!=null)
      out.write(value);
    out.write("\">\n");

  } // end render

  /*--------------------------------------------------------------------------------
   * Implementations from interface DialogField
   *--------------------------------------------------------------------------------
   */

  public String getName()
  {
    return name;

  } // end getName

  public Object getValue()
  {
    return value;

  } // end getValue

  public void setValue(Object o)
  {
    value = (o==null) ? null : o.toString();

  } // end setValue

  public void setValueFrom(RequestInput ri)
  {
    value = ri.getParameter(name);

  } // end setValueFrom

  public boolean isRequired()
  {
    return false;

  } // end isRequired

  public boolean isFile()
  {
    return false;

  } // end isFile

  public boolean isHidden()
  {
    return true;

  } // end isHidden

  public void validate() throws ValidationException
  { // do nothing
  } // end validate

  public boolean isEnabled()
  {
    return true;

  } // end isEnabled

  public void setEnabled(boolean flag)
  { // do nothing
  } // end setEnabled

  public Object sendMessage(String msg, Object data)
  {
    return null;

  } // end sendMessage

  public DialogField duplicate()
  {
    return new HiddenField(this);

  } // end duplicate

} // end class HiddenField
