/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.ui.dlg;

import java.io.IOException;
import java.util.*;
import org.w3c.dom.*;
import com.silverwrist.util.*;
import com.silverwrist.venice.except.*;
import com.silverwrist.venice.ui.*;

public abstract class PickListField extends BaseDialogField
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private List choices;

  /*--------------------------------------------------------------------------------
   * Constructors
   *--------------------------------------------------------------------------------
   */

  protected PickListField(String name, String caption, String caption2, boolean required, List choices)
  {
    super(false,name,caption,caption2,required);
    this.choices = choices;

  } // end constructor

  protected PickListField(Element elt, List choices) throws ConfigException
  {
    super(false,elt,true,true);
    this.choices = choices;

  } // end constructor

  protected PickListField(PickListField other)
  {
    super(other);
    this.choices = other.choices;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Abstract functions which MUST be overriden
   *--------------------------------------------------------------------------------
   */

  protected abstract String getChoiceName(Object o);

  protected abstract String getChoiceValue(Object o);

  /*--------------------------------------------------------------------------------
   * Overrides from class BaseDialogField
   *--------------------------------------------------------------------------------
   */

  protected void renderField(RequestOutput out) throws IOException
  {
    out.write("<SELECT CLASS=\"content\" NAME=\"" + getName() + "\" SIZE=1");
    if (!isEnabled())
      out.write(" DISABLED");
    out.write(">\n");
    Iterator it = choices.iterator();
    String val = getStringValue();
    while (it.hasNext())
    { // loop through the list and render the choices
      Object ch = it.next();
      String ch_name = getChoiceName(ch);
      out.write("<OPTION VALUE=\"" + ch_name + "\"");
      if (ch_name.equals(val))
	out.write(" SELECTED");
      out.write(">" + StringUtil.encodeHTML(getChoiceValue(ch)) + "</OPTION>\n");

    } // end while

    out.write("</SELECT>\n");  // all done

  } // end render

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public List getChoicesList()
  {
    return choices;

  } // end getChoicesList

  public void setChoicesList(List list)
  {
    this.choices = list;

  } // end setChoicesList

} // end class PickListField
