/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.ui.dlg;

import java.io.IOException;
import java.util.*;
import org.w3c.dom.*;
import com.silverwrist.util.*;
import com.silverwrist.venice.except.*;
import com.silverwrist.venice.ui.*;

public class TimeZoneListField extends PickListField
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  public static final String TAGNAME = "tzlist";

  private static final List tz_list;

  /*--------------------------------------------------------------------------------
   * Constructors
   *--------------------------------------------------------------------------------
   */

  public TimeZoneListField(String name, String caption, String caption2, boolean required)
  {
    super(name,caption,caption2,required,tz_list);

  } // end constructor

  public TimeZoneListField(Element elt) throws ConfigException
  {
    super(elt,tz_list);

  } // end constructor

  protected TimeZoneListField(TimeZoneListField other)
  {
    super(other);

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Overrides from class PickListField
   *--------------------------------------------------------------------------------
   */

  protected String getChoiceName(Object o)
  {
    return o.toString();

  } // end getChoiceName

  protected String getChoiceValue(Object o)
  {
    return o.toString();

  } // end getChoiceValue

  /*--------------------------------------------------------------------------------
   * Implementations from interface DialogField
   *--------------------------------------------------------------------------------
   */

  public Object getValue()
  {
    return TimeZone.getTimeZone(super.getValue().toString());

  } // end getValue

  public void setValue(Object o)
  {
    if ((o!=null) && (o instanceof TimeZone))
      super.setValue(((TimeZone)o).getID());
    else
      super.setValue(o);

  } // end setValue

  public DialogField duplicate()
  {
    return new TimeZoneListField(this);

  } // end duplicate

  /*--------------------------------------------------------------------------------
   * Static initializer
   *--------------------------------------------------------------------------------
   */

  static
  { // get the list of IDs, sort them, and save them
    String ids[] = TimeZone.getAvailableIDs();
    Arrays.sort(ids);
    tz_list = Collections.unmodifiableList(Arrays.asList(ids));

  } // end static initializer

} // end class TimeZoneListField
