/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.ui.helpers;

import java.io.IOException;
import com.silverwrist.util.StringUtil;
import com.silverwrist.venice.ui.*;

public class ErrorBox extends ThrowableContent implements ContentDirect, ColorSelectors, LinkTypes
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  private static final String DEFAULT_TITLE = "Error!";

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private String title;
  private String back;
  private int back_linktype;

  /*--------------------------------------------------------------------------------
   * Constructors
   *--------------------------------------------------------------------------------
   */

  public ErrorBox(String title, String message, String back, int back_linktype)
  {
    super(message);
    this.title = title;
    this.back = back;
    this.back_linktype = back_linktype;

    if (this.title==null)
      this.title = DEFAULT_TITLE;

  } // end constructor

  public ErrorBox(String title, String message, String back)
  {
    this(title,message,back,SERVLET);

  } // end constructor

  public ErrorBox(String title, Throwable t, String back, int back_linktype)
  {
    super(t);
    this.title = title;
    this.back = back;
    this.back_linktype = back_linktype;

    if (this.title==null)
      this.title = DEFAULT_TITLE;

  } // end constructor

  public ErrorBox(String title, Throwable t, String back)
  {
    this(title,t,back,SERVLET);

  } // end constructor

  public ErrorBox(String title, String message, Throwable t, String back, int back_linktype)
  {
    super(message,t);
    this.title = title;
    this.back = back;
    this.back_linktype = back_linktype;

    if (this.title==null)
      this.title = DEFAULT_TITLE;

  } // end constructor

  public ErrorBox(String title, String message, Throwable t, String back)
  {
    this(title,message,t,back,SERVLET);

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Implementations from interface Content
   *--------------------------------------------------------------------------------
   */

  public boolean needFrame()
  {
    return true;

  } // end needFrame

  public int getMenuSelector()
  {
    return MENU_SELECTOR_NOCHANGE;

  } // end getMenuSelector

  public String getPageTitle(RequestOutput ro)
  {
    return title;

  } // end getPageTitle

  public String getPageQID()
  {
    return null;

  } // end getPageQID

  /*--------------------------------------------------------------------------------
   * Implementations from interface ContentDirect
   *--------------------------------------------------------------------------------
   */

  public void render(RequestOutput out) throws IOException
  {
    out.write("<P><TABLE ALIGN=CENTER WIDTH=\"70%\" BORDER=1 CELLPADDING=2 CELLSPACING=1><TR VALIGN=MIDDLE>"
	      + "<TD ALIGN=CENTER BGCOLOR=\"" + out.getColor(ERROR_TITLE_BACKGROUND) + "\">\n"
	      + out.getFontTag(ERROR_TITLE_FOREGROUND,"errorbox") + StringUtil.encodeHTML(title)
	      + "</FONT>\n</TD></TR>" + "<TR VALIGN=MIDDLE><TD ALIGN=CENTER>\n"
	      + out.getFontTag(CONTENT_FOREGROUND,"errorbox") + "<P>" + StringUtil.encodeHTML(getMessage())
	      + "<P>\n");
    if (back==null)
      out.write("Use your browser's <B>Back</B> button to go back.\n");
    else
      out.write("<A HREF=\"" + out.formatURL(back,back_linktype) + "\">Go back.</A>\n");
    out.write("<P></FONT></TD></TR></TABLE><P>\n");
    if (canPrintStackTrace())
    { // put the stack trace in an HTML comment so we can see what may be going on...
      out.write("<!--\n");
      out.writeStackTrace(this);
      out.write("\n-->\n");

    } // end if

  } // end render

} // end class ErrorBox
