/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.ui.jsp;

import java.io.IOException;
import javax.servlet.jsp.*;
import javax.servlet.jsp.tagext.*;
import com.silverwrist.venice.core.*;
import com.silverwrist.venice.ui.*;

public class FrameBannerAdTag extends VeniceTagSupport
{
  /*--------------------------------------------------------------------------------
   * Overrides from class TagSupport
   *--------------------------------------------------------------------------------
   */

  public int doStartTag() throws JspException
  {
    StringBuffer write_data = new StringBuffer();
    Advertisement advert;
    RequestInput ri = getRequestInput();

    // Find an ad.
    UserContext user = ri.getUser();
    if (user.isLoggedIn())
      advert = user.selectAd();
    else
      advert = ri.getEngine().selectAd();
    if (advert!=null)
    { // we have an advertisement - figure out how to render it
      String tmp = advert.getImagePath();
      String full_image_path;
      if (advert.getImagePathStyle()==Advertisement.CONTEXT_RELATIVE)
      { // compute a context-relative path for the <IMG SRC>
	if (tmp.startsWith("/"))
	  full_image_path = ri.getContextPath() + tmp;
	else
	  full_image_path = ri.getContextPath() + "/" + tmp;

      } // end if
      else  // can't figure it out
	full_image_path = null;

      if (full_image_path!=null)
      { // compose the HTML fragment
	tmp = advert.getLinkURL();
	if (tmp!=null)
	  write_data.append("<A HREF=\"").append(tmp).append("\">");
	write_data.append("<IMG SRC=\"").append(full_image_path).append("\" ALT=\"");
	String tmp2 = advert.getCaption();
	if (tmp2!=null)
	  write_data.append(tmp2);
	write_data.append("\" ALIGN=RIGHT WIDTH=468 HEIGHT=60 HSPACE=2 VSPACE=2 BORDER=0>");
	if (tmp!=null)
	  write_data.append("</A>");

      } // end if
      else // path not computable - just write some junk
	write_data.append("&nbsp;");

    } // end if
    else // no ad found - just write some junk
      write_data.append("&nbsp;");

    try
    { // write out what we came here to accomplish
      JspWriter out = pageContext.getOut();
      out.write(write_data.toString());

    } // end try
    catch (IOException e)
    { // convert the I/O error into something the servlet engine can deal with
      throw new JspTagException("error writing advertisement info - " + e.getMessage());

    } // end catch

    return SKIP_BODY;

  } // end doStartTag

} // end class FrameBannerAdTag
