/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.ui.jsp;

import java.io.IOException;
import javax.servlet.jsp.*;
import javax.servlet.jsp.tagext.*;
import com.silverwrist.venice.ui.*;

public class UtilButtonTag extends VeniceTagSupport
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private String type = "img";
  private String id = null;

  /*--------------------------------------------------------------------------------
   * Overrides from class TagSupport
   *--------------------------------------------------------------------------------
   */

  public int doStartTag() throws JspException
  {
    if (id==null)
      throw new JspTagException("<util:button/> ID not specified!");
    if (!(type.equals("img") || type.equals("input")))
      throw new JspTagException("<util:button/> type not valid!");

    String data;
    if (type.equals("img"))
      data = getRequestOutput().getButtonVisual(id);
    else
      data = getRequestOutput().getButtonInput(id);

    try
    { // write out what we came here to accomplish
      JspWriter out = pageContext.getOut();
      out.write(data);

    } // end try
    catch (IOException e)
    { // convert the I/O error into something the servlet engine can deal with
      throw new JspTagException("error writing button - " + e.getMessage());

    } // end catch

    return SKIP_BODY;

  } // end doStartTag

  public void release()
  {
    super.release();
    type = "img";
    id = null;

  } // end release
  
  /*--------------------------------------------------------------------------------
   * Attribute set functions
   *--------------------------------------------------------------------------------
   */

  public void setType(String s)
  {
    type = s.trim().toLowerCase();

  } // end setType

  public void setId(String s)
  {
    id = s;

  } // end setId

} // end class UtilButtonTag
