/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.ui.jsp;

import java.io.IOException;
import java.net.URLEncoder;
import javax.servlet.jsp.*;
import javax.servlet.jsp.tagext.*;
import com.silverwrist.util.StringUtil;
import com.silverwrist.venice.ui.*;

public class UtilFormTag extends VeniceTagSupport
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  private static final String LOCATION_PARAM = "${location}";

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private String verb = null;
  private String action = null;
  private String type = null;
  private String cls = null;
  private String isfile = null;

  /*--------------------------------------------------------------------------------
   * Overrides from class TagSupport
   *--------------------------------------------------------------------------------
   */

  public int doStartTag() throws JspException
  {
    // Check the parameters!
    if (verb==null)
      verb = "POST";
    if (action==null)
      throw new JspTagException("<util:form/> action not specified!");
    if (type==null)
      throw new JspTagException("<util:form/> type not specified!");
    RequestInput ri = getRequestInput();
    int ityp = ri.convertLinkType(type);
    if (ityp==-1)
      throw new JspTagException("<util:form/> invalid action type!");

    // Do parameter replacement on the ACTION string if necessary.
    if (action.indexOf(LOCATION_PARAM)>=0)
      action = StringUtil.replaceAllInstances(action,LOCATION_PARAM,URLEncoder.encode(ri.getLocation()));

    try
    { // write out what we came here to accomplish
      JspWriter out = pageContext.getOut();
      out.write("<FORM METHOD=\"" + verb + "\" ");
      if (cls!=null)
	out.write("CLASS=\"" + cls + "\" ");
      if ((isfile!=null) && isfile.equals("true"))
	out.write("ENCTYPE=\"multipart/form-data\" ");
      out.write("ACTION=\"" + ri.formatURL(action,ityp) + "\">");

    } // end try
    catch (IOException e)
    { // convert the I/O error into something the servlet engine can deal with
      throw new JspTagException("error writing <FORM> tag - " + e.getMessage());

    } // end catch

    return EVAL_BODY_INCLUDE;

  } // end doStartTag

  public int doEndTag() throws JspException
  {
    try
    { // write out what we came here to accomplish
      JspWriter out = pageContext.getOut();
      out.write("</FORM>");

    } // end try
    catch (IOException e)
    { // convert the I/O error into something the servlet engine can deal with
      throw new JspTagException("error writing </FORM> tag - " + e.getMessage());

    } // end catch

    return EVAL_PAGE;

  } // end doEndTag

  public void release()
  {
    super.release();
    verb = null;
    action = null;
    type = null;
    cls = null;
    isfile = null;

  } // end release

  /*--------------------------------------------------------------------------------
   * Attribute set functions
   *--------------------------------------------------------------------------------
   */

  public void setVerb(String s)
  {
    verb = s;

  } // end setVerb

  public void setAction(String s)
  {
    action = s;

  } // end setAction

  public void setType(String s)
  {
    type = s;

  } // setType

  public void setAclass(String s)
  {
    cls = s;

  } // end setAclass

  public void setIsfile(String s)
  {
    isfile = s;

  } // end setIsfile

} // end class UtilFormTag

