/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.ui.jsp;

import java.io.IOException;
import java.net.URLEncoder;
import javax.servlet.jsp.*;
import javax.servlet.jsp.tagext.*;
import com.silverwrist.util.StringUtil;
import com.silverwrist.venice.ui.*;

public class UtilXLinkTag extends VeniceBodyTagSupport
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  private static final String LOCATION_PARAM = "${location}";

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private String href = null;
  private int type = -1;
  private String cls = null;
  private String target = null;
  private String text = null;
  private String title = null;

  /*--------------------------------------------------------------------------------
   * Overrides from class BodyTagSupport
   *--------------------------------------------------------------------------------
   */

  public int doStartTag()
  {
    return EVAL_BODY_TAG;

  } // end doStartTag

  public int doAfterBody()
  {
    return SKIP_BODY;

  } // end doAfterBody

  public int doEndTag() throws JspException
  {
    // Do some shorts-checking on our stored data.
    if (href==null)
      throw new JspTagException("<util:xlink/> does not have a <util:href/>!");
    if (type<0)
      throw new JspTagException("<util:xlink/> does not have a <util:href/>!");
    if (text==null)
      throw new JspTagException("<util:xlink/> does not have a <util:text/>!");

    // Do parameter replacement on the HREF string if necessary.
    RequestInput ri = getRequestInput();
    if (href.indexOf(LOCATION_PARAM)>=0)
      href = StringUtil.replaceAllInstances(href,LOCATION_PARAM,URLEncoder.encode(ri.getLocation()));

    try
    { // write out what we came here to accomplish
      JspWriter out = pageContext.getOut();
      out.write("<A ");
      if (cls!=null)
	out.write("CLASS=\"" + cls + "\" ");
      out.write("HREF=\"" + ri.formatURL(href,type) + "\"");
      if (title!=null)
	out.write(" TITLE=\"" + title + "\"");
      if (target!=null)
	out.write(" TARGET=\"" + target + "\"");
      out.write(">" + text + "</A>");

    } // end try
    catch (IOException e)
    { // convert the I/O error into something the servlet engine can deal with
      throw new JspTagException("error writing <A> tag - " + e.getMessage());

    } // end catch

    return EVAL_PAGE;

  } // end doEndTag

  public void release()
  {
    super.release();
    href = null;
    type = -1;
    cls = null;
    target = null;
    text = null;
    title = null;

  } // end release

  /*--------------------------------------------------------------------------------
   * Attribute set functions
   *--------------------------------------------------------------------------------
   */

  public void setAclass(String s)
  {
    cls = s;

  } // end setAclass

  public void setTarget(String s)
  {
    target = s;

  } // end setTarget

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  final void setLink(String href, int type)
  {
    this.href = href;
    this.type = type;

  } // end setLink

  final void setText(String text)
  {
    this.text = text;

  } // end setText

  final void setTitle(String title)
  {
    this.title = title;

  } // end setTitle

} // end class UtilXLinkTag
