/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.ui.script;

import com.silverwrist.venice.except.VeniceException;

public class ScriptingException extends VeniceException
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private String source = null;
  private String language = null;

  /*--------------------------------------------------------------------------------
   * Constructors
   *--------------------------------------------------------------------------------
   */

  /**
   * Constructs a new <CODE>ScriptingException</CODE>.
   */
  public ScriptingException()
  {
    super();

  } // end constructor

  /**
   * Constructs a new <CODE>ScriptingException</CODE> with a text message.
   *
   * @param msg The message to set in this exception.
   */
  public ScriptingException(String msg)
  {
    super(msg);

  } // end constructor

  /**
   * Constructs a new <CODE>ScriptingException</CODE> wrapping another exception.
   *
   * @param inner The exception wrapped by this one.
   */
  public ScriptingException(Throwable inner)
  {
    super(inner);

  } // end constructor

  /**
   * Constructs a new <CODE>ScriptingException</CODE> wrapping another exception.
   *
   * @param msg The message to set in this exception.
   * @param inner The exception wrapped by this one.
   */
  public ScriptingException(String msg, Throwable inner)
  {
    super(msg,inner);

  } // end constructor

  public ScriptingException(String source, String language, String msg)
  {
    super(msg);
    this.source = source;
    this.language = language;

  } // end constructor

  public ScriptingException(String source, String language, String msg, Throwable inner)
  {
    super(msg,inner);
    this.source = source;
    this.language = language;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Overrides from class Object
   *--------------------------------------------------------------------------------
   */

  public String toString()
  {
    if ((source==null) || (language==null))
      return super.toString();
    StringBuffer buf = new StringBuffer(getClass().getName());
    buf.append(": error executing ").append(source).append(" [").append(language).append("]:\n");
    buf.append(getMessage());
    return buf.toString();

  } // end toString

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public final String getSource()
  {
    return source;

  } // end getSource

  public final String getLanguage()
  {
    return language;

  } // end getLanguage

} // end class ScriptingException
