/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.ui.servlet;

import javax.servlet.http.HttpServletResponse;
import org.apache.log4j.*;
import com.silverwrist.venice.core.*;
import com.silverwrist.venice.except.*;
import com.silverwrist.venice.ui.*;
import com.silverwrist.venice.ui.helpers.*;

public class GetImageServlet extends BaseServlet
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  private static Category logger = Category.getInstance(GetImageServlet.class);

  /*--------------------------------------------------------------------------------
   * Implementations from class BaseServlet
   *--------------------------------------------------------------------------------
   */

  public Object process(RequestInput req) throws Exception, ThrowableContent
  {
    try
    { // parse the image ID, get the data, and return it
      int imgid = Integer.parseInt(req.getPathInfo().substring(1));
      BinaryData image = req.getEngine().loadImage(imgid);
      return new BinaryDataContent(image);

    } // end try
    catch (NumberFormatException nfe)
    { // invalid image URL
      return new HTTPError(HttpServletResponse.SC_BAD_REQUEST,nfe);

    } // end catch
    catch (DataException de)
    { // unable to get the user name
      return new HTTPError(HttpServletResponse.SC_INTERNAL_SERVER_ERROR,de);

    } // end catch

  } // end process

} // end class GetImageServlet
