/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.ui.servlet;

import java.io.*;
import org.apache.log4j.*;
import com.silverwrist.venice.core.*;
import com.silverwrist.venice.except.*;
import com.silverwrist.venice.ui.*;
import com.silverwrist.venice.ui.helpers.*;
import com.silverwrist.venice.ui.view.*;

public class PasswordRecoveryServlet extends BaseServlet
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  private static Category logger = Category.getInstance(PasswordRecoveryServlet.class);

  /*--------------------------------------------------------------------------------
   * Implementations from class BaseServlet
   *--------------------------------------------------------------------------------
   */

  public Object process(RequestInput req)
  {
    int uid, auth;
    try
    { // retrieve UID and authentication strings from URL
      String foo = req.getPathInfo().substring(1);
      int n = foo.indexOf('.');
      if (n<0)
	return new ErrorBox(null,"Invalid parameters to password recovery.","top.js.vs");
      uid = Integer.parseInt(foo.substring(0,n));
      auth = Integer.parseInt(foo.substring(n+1));

    } // end try
    catch (NumberFormatException nfe)
    { // invalid parameters passed...
      return new ErrorBox(null,"Invalid parameters to password recovery.","top.js.vs");

    } // end catch

    try
    { // complete the password change
      req.getEngine().completePasswordChange(uid,auth);

      // now return a "password changed" page
      req.setLocation("top.js.vs");  // lie so that we get the "Log In" link up top
      JSPView view = new JSPView("Your Password Has Been Changed","password_changed.jsp");
      view.setMenuSelector(Content.MENU_SELECTOR_TOP);
      return view;

    } // end try
    catch (DataException de)
    { // there was a database error changing your password
      return new ErrorBox("Database Error","Database error changing password: " + de.getMessage(),"top.js.vs");

    } // end catch
    catch (AccessError ae)
    { // this indicates a problem with the request ID or authentication
      return new ErrorBox("Invalid Request",ae.getMessage(),"top.js.vs");

    } // end catch
    catch (EmailException ee)
    { // error sending the confirmation email
      return new ErrorBox("E-mail Error","E-mail error sending update: " + ee.getMessage(),"top.js.vs");

    } // end catch

  } // end process

} // end class PasswordRecoveryServlet
